<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'admin_init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'cricket_colours',
        'title'       => 'Colours'
      )
    ),
    'settings'        => array( 
      array(
        'id'          => 'cricket_main_heading_font',
        'label'       => 'Main Heading Font',
        'desc'        => 'Set Color (#660066), Family, Size (20px) and Weight (bold).  Set family to \'font-family\' for default.  Defaults in brackets',
        'std'         => array('font-color' => '#660066','font-size' => '20px','font-weight' => 'bold'),
        'type'        => 'typography',
        'section'     => 'cricket_colours',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'cricket_sub_heading_font',
        'label'       => 'Sub Heading Font',
        'desc'        => 'Set Color (#660066), Family, Size (15px) and Weight (bold).',
        'std'         => array('font-color' => '#660066','font-size' => '15px','font-weight' => 'bold'),
        'type'        => 'typography',
        'section'     => 'cricket_colours',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'cricket_menu_font',
        'label'       => 'Menu Font',
        'desc'        => 'Set Color (#660066), Family, Size (13px) and Weight (bold).',
        'std'         => array('font-color' => '#660066','font-size' => '13px','font-weight' => 'bold'),
        'type'        => 'typography',
        'section'     => 'cricket_colours',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'cricket_menu_background',
        'label'       => 'Menu background',
        'desc'        => 'Background colour for menu: Default #f9f9f9',
        'std'         => '#f9f9f9',
        'type'        => 'colorpicker',
        'section'     => 'cricket_colours',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'cricket_dark_background_colour',
        'label'       => 'Darker background colour',
        'desc'        => 'Default #D6B9D5',
        'std'         => '#D6B9D5',
        'type'        => 'colorpicker',
        'section'     => 'cricket_colours',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'plain_side_menu',
        'label'       => 'Plain Side Menus',
        'desc'        => '',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'cricket_colours',
        'class'       => '',
        'choices'     => array(
          array( 
            'value' => 'yes',
            'label' => 'Yes' 
          ))
	)
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
      update_option( 'option_tree_settings', $custom_settings ); 
  }
}